# Diamond App skeleton

Read more about Diamond here: https://github.com/iandennismiller/flask-diamond

## usage

### clone the skeleton

```
git clone https://github.com/iandennismiller/diamond-app.git /tmp/diamond-app
```

### scaffold in the current directory

```
mrbob -w /tmp/diamond-app/skel
```

## Pre-requisites

```
pip install mr.bob
```
